@@ -6,7 +6,6 @@ from types import TracebackType
 from urllib.parse import SplitResult, parse_qsl, urlsplit
 
 from sqlalchemy import text
-from sqlalchemy.engine import RowProxy
 from sqlalchemy.sql import ClauseElement
 
 from databases.importer import import_from_string
@@ -26,16 +25,22 @@ class Database:
     }
 
     def __init__(
-        self, url: typing.Union[str, "DatabaseURL"], *, force_rollback: bool = False
+        self,
+        url: typing.Union[str, "DatabaseURL"],
+        *,
+        force_rollback: bool = False,
+        **options: typing.Any,
     ):
         self.url = DatabaseURL(url)
-        self._force_rollback = force_rollback
+        self.options = options
         self.is_connected = False
 
+        self._force_rollback = force_rollback
+
         backend_str = self.SUPPORTED_BACKENDS[self.url.dialect]
         backend_cls = import_from_string(backend_str)
         assert issubclass(backend_cls, DatabaseBackend)
-        self._backend = backend_cls(self.url)
+        self._backend = backend_cls(self.url, **self.options)
 
         # Connections are stored as task-local state.
         self._connection_context = ContextVar("connection_context")  # type: ContextVar
@@ -91,16 +96,25 @@ class Database:
 
     async def fetch_all(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.List[RowProxy]:
+    ) -> typing.List[typing.Mapping]:
         async with self.connection() as connection:
             return await connection.fetch_all(query, values)
 
     async def fetch_one(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> RowProxy:
+    ) -> typing.Optional[typing.Mapping]:
         async with self.connection() as connection:
             return await connection.fetch_one(query, values)
 
+    async def fetch_val(
+        self,
+        query: typing.Union[ClauseElement, str],
+        values: dict = None,
+        column: typing.Any = 0,
+    ) -> typing.Any:
+        async with self.connection() as connection:
+            return await connection.fetch_val(query, values, column=column)
+
     async def execute(
         self, query: typing.Union[ClauseElement, str], values: dict = None
     ) -> typing.Any:
@@ -115,7 +129,7 @@ class Database:
 
     async def iterate(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.AsyncGenerator[RowProxy, None]:
+    ) -> typing.AsyncGenerator[typing.Mapping, None]:
         async with self.connection() as connection:
             async for record in connection.iterate(query, values):
                 yield record
@@ -167,14 +181,23 @@ class Connection:
 
     async def fetch_all(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.Any:
+    ) -> typing.List[typing.Mapping]:
         return await self._connection.fetch_all(self._build_query(query, values))
 
     async def fetch_one(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.Any:
+    ) -> typing.Optional[typing.Mapping]:
         return await self._connection.fetch_one(self._build_query(query, values))
 
+    async def fetch_val(
+        self,
+        query: typing.Union[ClauseElement, str],
+        values: dict = None,
+        column: typing.Any = 0,
+    ) -> typing.Any:
+        row = await self._connection.fetch_one(self._build_query(query, values))
+        return None if row is None else row[column]
+
     async def execute(
         self, query: typing.Union[ClauseElement, str], values: dict = None
     ) -> typing.Any:
